@@ -42,6 +42,7 @@
 #define HAVE_LIMITS_H 1
 #define HAVE_LINK_H 1
 #define HAVE_LINUX_UNISTD_H 1
+#define HAVE_LINUX_MMAN_H 1
 #define HAVE_LOCALE_H 1
 #define HAVE_MALLOC_H 1
 #define HAVE_MEMORY_H 1
@@ -64,7 +65,6 @@
 #define HAVE_SYS_FILE_H 1
 /* #undef HAVE_SYS_FPU_H */
 #define HAVE_SYS_IOCTL_H 1
-#define HAVE_SYS_IPC_H 1
 /* #undef HAVE_SYS_MALLOC_H */
 #define HAVE_SYS_MMAN_H 1
 /* #undef HAVE_SYS_NDIR_H */
@@ -73,7 +73,6 @@
 #define HAVE_SYS_PRCTL_H 1
 #define HAVE_SYS_RESOURCE_H 1
 #define HAVE_SYS_SELECT_H 1
-#define HAVE_SYS_SHM_H 1
 #define HAVE_SYS_SOCKET_H 1
 /* #undef HAVE_SYS_SOCKIO_H */
 #define HAVE_SYS_UTSNAME_H 1
@@ -104,7 +103,6 @@
 /* Libraries */
 /* #undef HAVE_LIBWRAP */
 #define HAVE_SYSTEMD 1
-/* #undef HAVE_CRC32_VPMSUM */
 
 /* Does "struct timespec" have a "sec" and "nsec" field? */
 /* #undef HAVE_TIMESPEC_TS_SEC */
@@ -122,7 +120,6 @@
 /* Functions we may want to use. */
 #define HAVE_ACCEPT4 1
 #define HAVE_ACCESS 1
-/* #undef HAVE_AIOWAIT */
 #define HAVE_ALARM 1
 #define HAVE_ALLOCA 1
 /* #undef HAVE_BFILL */
@@ -148,6 +145,7 @@
 #define HAVE_GETHOSTBYADDR_R 1
 /* #undef HAVE_GETHRTIME */
 #define HAVE_GETPAGESIZE 1
+/* #undef HAVE_GETPAGESIZES */
 #define HAVE_GETPASS 1
 /* #undef HAVE_GETPASSPHRASE */
 #define HAVE_GETPWNAM 1
@@ -160,19 +158,19 @@
 /* #undef gmtime_r */
 #define HAVE_IN_ADDR_T 1
 #define HAVE_INITGROUPS 1
-#define HAVE_LARGE_PAGE_OPTION 1
 #define HAVE_LDIV 1
 #define HAVE_LRAND48 1
 #define HAVE_LOCALTIME_R 1
 #define HAVE_LSTAT 1
 #define HAVE_MEMALIGN 1
 /* #define HAVE_MLOCK 1 see Bug#54662 */
-#define HAVE_NPTL 1
 #define HAVE_NL_LANGINFO 1
 #define HAVE_MADVISE 1
 #define HAVE_DECL_MADVISE 1
 /* #undef HAVE_DECL_MHA_MAPSIZE_VA */
 #define HAVE_MALLINFO 1
+/* #undef HAVE_MALLINFO2 */
+/* #undef HAVE_MALLOC_ZONE */
 #define HAVE_MEMCPY 1
 #define HAVE_MEMMOVE 1
 #define HAVE_MKSTEMP 1
@@ -192,6 +190,7 @@
 #define HAVE_PTHREAD_ATTR_SETSCOPE 1
 #define HAVE_PTHREAD_ATTR_SETSTACKSIZE 1
 /* #undef HAVE_PTHREAD_CONDATTR_CREATE */
+#define HAVE_PTHREAD_GETAFFINITY_NP 1
 #define HAVE_PTHREAD_KEY_DELETE 1
 /* #undef HAVE_PTHREAD_KILL */
 #define HAVE_PTHREAD_RWLOCK_RDLOCK 1
@@ -240,7 +239,6 @@
 /* Symbols we may use */
 /* #undef HAVE_SYS_ERRLIST */
 /* used by stacktrace functions */
-#define HAVE_BSS_START 1
 #define HAVE_BACKTRACE 1
 #define HAVE_BACKTRACE_SYMBOLS 1
 #define HAVE_BACKTRACE_SYMBOLS_FD 1
@@ -382,9 +380,6 @@
 
 #define HAVE_GCC_C11_ATOMICS 1
 /* #undef HAVE_SOLARIS_ATOMIC */
-#define HAVE_DECL_SHM_HUGETLB 1
-#define HAVE_LINUX_LARGE_PAGES 1
-#define HUGETLB_USE_PROC_MEMINFO 1
 /* #undef NO_FCNTL_NONBLOCK */
 #define NO_ALARM 1
 
@@ -494,8 +489,7 @@
 #define HAVE_CHARSET_ucs2 1
 #define HAVE_CHARSET_ujis 1
 #define HAVE_CHARSET_utf8mb4 1
-/* #undef HAVE_CHARSET_utf8mb3 */
-#define HAVE_CHARSET_utf8 1
+#define HAVE_CHARSET_utf8mb3 1
 #define HAVE_CHARSET_utf16 1
 #define HAVE_CHARSET_utf32 1
 #define HAVE_UCA_COLLATIONS 1
@@ -533,18 +527,19 @@
 /* #undef SO_EXT */
 
 #define MYSQL_VERSION_MAJOR 10
-#define MYSQL_VERSION_MINOR 4
-#define MYSQL_VERSION_PATCH 8
+#define MYSQL_VERSION_MINOR 5
+#define MYSQL_VERSION_PATCH 11
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.4.8"
+#define PACKAGE_STRING "MySQL Server 10.5.11"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.4.8"
-#define VERSION "10.4.8"
+#define PACKAGE_VERSION "10.5.11"
+#define VERSION "10.5.11"
 #define PROTOCOL_VERSION 10
+#define PCRE2_CODE_UNIT_WIDTH 8
 
 #define MALLOC_LIBRARY "system"
 
